@@ -1,15 +1,12 @@
-from __future__ import print_function
-
-try:
-    import fcntl
-except:
-    fcntl = None
+import fcntl
 import os
-import sys
-from subprocess import Popen, PIPE
 import socket
+import sys
+from subprocess import PIPE, Popen
+
 from netrepr import NetRepr, RemoteObjectPool, RemoteObjectReference
 
+
 IMPORT_MODULES = ["netrepr", "remote_console", "remote_pipe", "remote_bootstrap"]
 source = []
 for fn in IMPORT_MODULES:
@@ -19,12 +16,6 @@ for fn in IMPORT_MODULES:
 SOURCE = repr("".join(source)) + "\n"
 
 
-def ensure_utf8(s):
-    if isinstance(s, unicode):
-        s = s.encode("utf-8")
-    return s
-
-
 def bind_and_listen(hostport):
     if isinstance(hostport, str):
         host, port = hostport.split(":")
@@ -91,13 +82,13 @@ def client_loop(f):
                 args = map(neteval, command[3:])
                 code = None
                 rval = None
-                if name == "RemoteConsole.raw_input":
+                if name == "RemoteConsole.input":
                     try:
-                        rval = raw_input(*args)
+                        rval = input(*args)
                     except EOFError:
                         code = "raise EOFError"
                 elif name == "RemoteConsole.write":
-                    sys.stdout.write(ensure_utf8(args[0]))
+                    sys.stdout.write(args[0])
                 elif name == "RemoteConsole.displayhook":
                     pass
                     obj = args[0]
@@ -109,8 +100,8 @@ def client_loop(f):
                         print(repr(obj))
                 elif name.startswith("RemoteFileLike."):
                     fh = getattr(sys, args[0])
-                    meth = getattr(fh, name[len("RemoteFileLike.") :])
-                    rval = meth(*map(ensure_utf8, args[1:]))
+                    meth = getattr(fh, name[len("RemoteFileLike.") :])  # noqa: E203
+                    rval = meth(*args[1:])
                 else:
                     print(name, args)
                 if code is None:
