@@ -39,28 +39,28 @@ struct objc10_object {
 };
 
 struct PyObjC_ivar {
-    char* name;
-    size_t size;
+    char*   name;
+    size_t  size;
     uint8_t alignment;
-    char* types;
+    char*   types;
 };
 
 static Protocol**
 compat_objc_copyProtocolList(unsigned int* outCount)
 {
     Protocol** protocols = NULL;
-    *outCount = 0;
+    *outCount            = 0;
 
     uint32_t image_count, image_index;
     image_count = _dyld_image_count();
     for (image_index = 0; image_index < image_count; image_index++) {
-        uint32_t size = 0;
-        const struct mach_header* mh = _dyld_get_image_header(image_index);
-        intptr_t slide = _dyld_get_image_vmaddr_slide(image_index);
-        ProtocolTemplate* protos =
+        uint32_t                  size  = 0;
+        const struct mach_header* mh    = _dyld_get_image_header(image_index);
+        intptr_t                  slide = _dyld_get_image_vmaddr_slide(image_index);
+        ProtocolTemplate*         protos =
             (ProtocolTemplate*)(((char*)getsectdatafromheader(mh, SEG_OBJC, "__protocol",
-                                                              &size)) +
-                                slide);
+                                                              &size))
+                                + slide);
         uint32_t nprotos = size / sizeof(ProtocolTemplate);
         uint32_t i;
 
@@ -97,14 +97,14 @@ compat_objc_getProtocol(const char* name)
     uint32_t image_count, image_index;
     image_count = _dyld_image_count();
     for (image_index = 0; image_index < image_count; image_index++) {
-        uint32_t size = 0;
-        const struct mach_header* mh = _dyld_get_image_header(image_index);
-        intptr_t slide = _dyld_get_image_vmaddr_slide(image_index);
+        uint32_t                  size  = 0;
+        const struct mach_header* mh    = _dyld_get_image_header(image_index);
+        intptr_t                  slide = _dyld_get_image_vmaddr_slide(image_index);
 
         ProtocolTemplate* protos =
             (ProtocolTemplate*)(((char*)getsectdatafromheader(mh, SEG_OBJC, "__protocol",
-                                                              &size)) +
-                                slide);
+                                                              &size))
+                                + slide);
         uint32_t nprotos = size / sizeof(ProtocolTemplate);
         uint32_t i;
 
@@ -129,11 +129,11 @@ compat_objc_registerClassPair(Class cls)
     /* Add the list in the official way, just in case class_addMethods
      * does something special.
      */
-    list = cls->methodLists[0];
+    list                = cls->methodLists[0];
     cls->methodLists[0] = (struct objc_method_list*)-1;
     class_addMethods(cls, list);
 
-    list = cls->isa->methodLists[0];
+    list                     = cls->isa->methodLists[0];
     cls->isa->methodLists[0] = (struct objc_method_list*)-1;
     class_addMethods(cls->isa, list);
 
@@ -144,7 +144,7 @@ static Class
 compat_objc_allocateClassPair(Class super_class, const char* name, size_t extra)
 {
     struct objc_class* result;
-    Class root_class;
+    Class              root_class;
 
     if (objc_getClass(name)) {
         return Nil;
@@ -162,7 +162,7 @@ compat_objc_allocateClassPair(Class super_class, const char* name, size_t extra)
     memset(result, 0, sizeof(struct objc_class) * 2 + extra);
 
     result->super_class = super_class;
-    result->isa = result + 1;
+    result->isa         = result + 1;
 
     result[0].methodLists = NULL;
     result[1].methodLists = NULL;
@@ -174,7 +174,7 @@ compat_objc_allocateClassPair(Class super_class, const char* name, size_t extra)
     if (result[0].name == NULL)
         goto error_cleanup;
 
-    result[1].name = result[0].name;
+    result[1].name        = result[0].name;
     result[0].methodLists = malloc(sizeof(struct objc_method_list*));
 
     if (result[0].methodLists == NULL)
@@ -206,18 +206,18 @@ compat_objc_allocateClassPair(Class super_class, const char* name, size_t extra)
         goto error_cleanup;
 
     result[0].methodLists[0]->method_count = 0;
-    result[0].methodLists[0]->obsolete = NULL;
+    result[0].methodLists[0]->obsolete     = NULL;
 
     result[1].methodLists[0] = malloc(sizeof(struct objc_method_list));
     if (result[1].methodLists[0] == NULL)
         goto error_cleanup;
 
     result[1].methodLists[0]->method_count = 0;
-    result[1].methodLists[0]->obsolete = NULL;
+    result[1].methodLists[0]->obsolete     = NULL;
 
     result[0].super_class = super_class;
     result[1].super_class = ((struct objc10_object*)super_class)->isa;
-    result[1].isa = ((struct objc10_object*)root_class)->isa;
+    result[1].isa         = ((struct objc10_object*)root_class)->isa;
 
     result[0].instance_size = super_class->instance_size;
     result[1].instance_size = result[1].super_class->instance_size;
@@ -265,7 +265,7 @@ static void
 compat_objc_disposeClassPair(Class cls)
 {
     struct objc_class* val = cls;
-    int i;
+    int                i;
 
     for (i = 0; i < 2; i++) {
         if (val[i].methodLists) {
@@ -294,7 +294,7 @@ compat_object_setClass(id obj, Class cls)
     if (obj == nil) {
         return Nil;
     }
-    prev = ((struct objc10_object*)obj)->isa;
+    prev                              = ((struct objc10_object*)obj)->isa;
     ((struct objc10_object*)obj)->isa = cls;
     return prev;
 }
@@ -315,15 +315,15 @@ static Method*
 compat_class_copyMethodList(Class cls, unsigned int* outCount)
 {
     struct objc_method_list* mlist;
-    void* iterator;
-    unsigned int count;
-    Method* result;
-    Method* tmp;
+    void*                    iterator;
+    unsigned int             count;
+    Method*                  result;
+    Method*                  tmp;
 
     iterator = NULL;
-    count = 0;
+    count    = 0;
 
-    mlist = class_nextMethodList(cls, &iterator);
+    mlist  = class_nextMethodList(cls, &iterator);
     result = NULL;
     while (mlist != NULL) {
         int i;
@@ -356,8 +356,8 @@ compat_class_copyMethodList(Class cls, unsigned int* outCount)
 static Ivar*
 compat_class_copyIvarList(Class cls, unsigned int* outCount)
 {
-    Ivar* list;
-    int i;
+    Ivar*                  list;
+    int                    i;
     struct objc_ivar_list* ivars = cls->ivars;
 
     if (ivars) {
@@ -387,12 +387,12 @@ compat_class_copyIvarList(Class cls, unsigned int* outCount)
 static Protocol**
 compat_class_copyProtocolList(Class cls, unsigned int* outCount)
 {
-    Protocol** list;
-    unsigned int count = 0;
+    Protocol**                 list;
+    unsigned int               count = 0;
     struct objc_protocol_list* protocol_list;
 
     protocol_list = cls->protocols;
-    list = malloc(0);
+    list          = malloc(0);
 
     while (protocol_list != NULL) {
         Protocol** tmp;
@@ -436,16 +436,16 @@ static BOOL
 compat_class_addMethod(Class cls, SEL name, IMP imp, const char* types)
 {
     struct objc_method_list* methodsToAdd;
-    struct objc_method* objcMethod;
+    struct objc_method*      objcMethod;
 
     methodsToAdd =
         malloc(sizeof(struct objc_method_list) + 2 * sizeof(struct objc_method));
     methodsToAdd->method_count = 1;
-    methodsToAdd->obsolete = NULL;
+    methodsToAdd->obsolete     = NULL;
 
-    objcMethod = methodsToAdd->method_list;
-    objcMethod->method_name = name;
-    objcMethod->method_imp = imp;
+    objcMethod               = methodsToAdd->method_list;
+    objcMethod->method_name  = name;
+    objcMethod->method_imp   = imp;
     objcMethod->method_types = (char*)types;
 
     class_addMethods(cls, methodsToAdd);
@@ -457,21 +457,21 @@ compat_preclass_addMethod(Class cls, SEL name, IMP imp, const char* types)
 {
     /* Resize in-place, this is only valid during class construction. */
     struct objc_method_list* new_list;
-    struct objc_method* objcMethod;
+    struct objc_method*      objcMethod;
 
     new_list =
-        realloc(cls->methodLists[0], sizeof(struct objc_method_list) +
-                                         (sizeof(struct objc_method) *
-                                          (cls->methodLists[0]->method_count + 1)));
+        realloc(cls->methodLists[0], sizeof(struct objc_method_list)
+                                         + (sizeof(struct objc_method)
+                                            * (cls->methodLists[0]->method_count + 1)));
     if (new_list == NULL) {
         return NO;
     }
 
     cls->methodLists[0] = new_list;
-    objcMethod = new_list->method_list + (new_list->method_count)++;
+    objcMethod          = new_list->method_list + (new_list->method_count)++;
 
-    objcMethod->method_name = name;
-    objcMethod->method_imp = imp;
+    objcMethod->method_name  = name;
+    objcMethod->method_imp   = imp;
     objcMethod->method_types = strdup(types);
     if (objcMethod == NULL) {
         new_list->method_count--;
@@ -487,12 +487,12 @@ compat_preclass_addIvar(Class cls, const char* name, size_t size, uint8_t align,
 {
     /* Update the class structure, only valid during class construction */
     struct objc_ivar_list* new_ivars;
-    struct objc_ivar* ivar;
+    struct objc_ivar*      ivar;
 
     if (cls->ivars) {
         new_ivars = realloc(
-            cls->ivars, sizeof(struct objc_ivar_list) +
-                            ((cls->ivars->ivar_count + 1) * sizeof(struct objc_ivar)));
+            cls->ivars, sizeof(struct objc_ivar_list)
+                            + ((cls->ivars->ivar_count + 1) * sizeof(struct objc_ivar)));
     } else {
         new_ivars = malloc(sizeof(struct objc_ivar_list) + sizeof(struct objc_ivar));
         new_ivars->ivar_count = 0;
@@ -502,8 +502,8 @@ compat_preclass_addIvar(Class cls, const char* name, size_t size, uint8_t align,
         return NO;
     }
 
-    cls->ivars = new_ivars;
-    ivar = new_ivars->ivar_list + new_ivars->ivar_count;
+    cls->ivars      = new_ivars;
+    ivar            = new_ivars->ivar_list + new_ivars->ivar_count;
     ivar->ivar_name = strdup(name);
 
     if (ivar->ivar_name == NULL) {
@@ -535,20 +535,20 @@ compat_preclass_addProtocol(Class cls, Protocol* protocol)
 
     if (cls->protocols) {
         protocols = realloc(cls->protocols,
-                            sizeof(struct objc_protocol_list) +
-                                (sizeof(Protocol*) * (cls->protocols->count + 1)));
+                            sizeof(struct objc_protocol_list)
+                                + (sizeof(Protocol*) * (cls->protocols->count + 1)));
 
     } else {
-        protocols = malloc(sizeof(struct objc_protocol_list) + sizeof(Protocol*));
+        protocols        = malloc(sizeof(struct objc_protocol_list) + sizeof(Protocol*));
         protocols->count = 0;
-        protocols->next = NULL;
+        protocols->next  = NULL;
     }
 
     if (protocols == NULL) {
         return NO;
     }
 
-    cls->protocols = protocols;
+    cls->protocols                    = protocols;
     protocols->list[protocols->count] = protocol;
     protocols->count++;
     return YES;
@@ -569,7 +569,7 @@ compat_method_getImplementation(Method m)
 static IMP
 compat_method_setImplementation(Method m, IMP imp)
 {
-    IMP result = m->method_imp;
+    IMP result    = m->method_imp;
     m->method_imp = imp;
     return result;
 }
@@ -609,8 +609,8 @@ static BOOL
 objc20_class_addMethodList(Class cls, struct PyObjC_method* list, unsigned int count)
 {
     unsigned int i;
-    BOOL r;
-    Method m;
+    BOOL         r;
+    Method       m;
 
     for (i = 0; i < count; i++) {
         r = class_addMethod(cls, list[i].name, list[i].imp, list[i].type);
@@ -639,11 +639,11 @@ compat_class_isMetaClass(Class cls)
 static BOOL
 compat_class_addMethodList(Class cls, struct PyObjC_method* list, unsigned int count)
 {
-    unsigned int i;
+    unsigned int             i;
     struct objc_method_list* method_list;
 
-    method_list = malloc(sizeof(struct objc_method_list) +
-                         ((count + 1) * sizeof(struct objc_method)));
+    method_list = malloc(sizeof(struct objc_method_list)
+                         + ((count + 1) * sizeof(struct objc_method)));
     if (method_list == NULL) {
         return NO;
     }
@@ -652,12 +652,12 @@ compat_class_addMethodList(Class cls, struct PyObjC_method* list, unsigned int c
            sizeof(struct objc_method_list) + ((count + 1) * sizeof(struct objc_method)));
 
     method_list->method_count = 0;
-    method_list->obsolete = 0;
+    method_list->obsolete     = 0;
 
     for (i = 0; i < count; i++) {
-        method_list->method_list[i].method_name = list[i].name;
+        method_list->method_list[i].method_name  = list[i].name;
         method_list->method_list[i].method_types = (char*)list[i].type;
-        method_list->method_list[i].method_imp = list[i].imp;
+        method_list->method_list[i].method_imp   = list[i].imp;
     }
 
     method_list->method_count = count;
@@ -682,7 +682,7 @@ compat_protocol_copyMethodDescriptionList(Protocol* p, BOOL isRequiredMethod,
                                           BOOL isInstanceMethod, unsigned int* outCount)
 {
     struct objc_method_description_list* list;
-    struct objc_method_description* result;
+    struct objc_method_description*      result;
 
     if (!isRequiredMethod) {
         *outCount = 0;
@@ -713,7 +713,7 @@ compat_protocol_copyMethodDescriptionList(Protocol* p, BOOL isRequiredMethod,
     for (i = 0; i < list->count; i++) {
         if (list->list[i].name == NULL)
             continue;
-        result[*outCount].name = list->list[i].name;
+        result[*outCount].name  = list->list[i].name;
         result[*outCount].types = list->list[i].types;
         (*outCount)++;
     }
@@ -758,7 +758,7 @@ compat_protocol_getMethodDescription(Protocol* p, SEL aSel, BOOL isRequiredMetho
                                      BOOL isInstanceMethod)
 {
     static struct objc_method_description empty_description = {NULL, NULL};
-    struct objc_method_description* result;
+    struct objc_method_description*       result;
     if (!isRequiredMethod) {
         return empty_description;
     }
@@ -790,45 +790,45 @@ compat_object_setIvar(id obj, Ivar ivar, id value)
 
 /* Dispatch table */
 BOOL (*PyObjC_protocol_conformsToProtocol)(Protocol* proto, Protocol* other) = NULL;
-const char* (*PyObjC_protocol_getName)(Protocol* p) = NULL;
+const char* (*PyObjC_protocol_getName)(Protocol* p)                          = NULL;
 struct objc_method_description* (*PyObjC_protocol_copyMethodDescriptionList)(
     Protocol* p, BOOL isRequiredMethod, BOOL isInstanceMethod,
-    unsigned int* outCount) = NULL;
-Protocol** (*PyObjC_protocol_copyProtocolList)(Protocol* proto,
+    unsigned int* outCount)                                            = NULL;
+Protocol** (*PyObjC_protocol_copyProtocolList)(Protocol*     proto,
                                                unsigned int* outCount) = NULL;
 struct objc_method_description (*PyObjC_protocol_getMethodDescription)(
     Protocol* p, SEL aSel, BOOL isRequiredMethod, BOOL isInstanceMethod) = NULL;
-id (*PyObjC_object_getIvar)(id obj, Ivar ivar) = NULL;
-void (*PyObjC_object_setIvar)(id obj, Ivar ivar, id value) = NULL;
-Class (*PyObjC_objc_allocateClassPair)(Class, const char*, size_t) = NULL;
-void (*PyObjC_objc_registerClassPair)(Class) = NULL;
-void (*PyObjC_objc_disposeClassPair)(Class) = NULL;
-Protocol** (*PyObjC_objc_copyProtocolList)(unsigned int*) = NULL;
-Protocol* (*PyObjC_objc_getProtocol)(const char* name) = NULL;
-BOOL (*PyObjC_preclass_addMethod)(Class, SEL, IMP, const char*) = NULL;
+id (*PyObjC_object_getIvar)(id obj, Ivar ivar)                           = NULL;
+void (*PyObjC_object_setIvar)(id obj, Ivar ivar, id value)               = NULL;
+Class (*PyObjC_objc_allocateClassPair)(Class, const char*, size_t)       = NULL;
+void (*PyObjC_objc_registerClassPair)(Class)                             = NULL;
+void (*PyObjC_objc_disposeClassPair)(Class)                              = NULL;
+Protocol** (*PyObjC_objc_copyProtocolList)(unsigned int*)                = NULL;
+Protocol* (*PyObjC_objc_getProtocol)(const char* name)                   = NULL;
+BOOL (*PyObjC_preclass_addMethod)(Class, SEL, IMP, const char*)          = NULL;
 BOOL(*PyObjC_preclass_addIvar)
 (Class cls, const char* name, size_t size, uint8_t alignment, const char* types) = NULL;
-BOOL (*PyObjC_preclass_addProtocol)(Class cls, Protocol* protocol) = NULL;
-Class (*PyObjC_object_getClass)(id obj) = NULL;
-Class (*PyObjC_object_setClass)(id obj, Class cls) = NULL;
-const char* (*PyObjC_object_getClassName)(id obj) = NULL;
-Method* (*PyObjC_class_copyMethodList)(Class, unsigned int*) = NULL;
-const char* (*PyObjC_class_getName)(Class) = NULL;
-size_t (*PyObjC_class_getInstanceSize)(Class) = NULL;
-Class (*PyObjC_class_getSuperclass)(Class) = NULL;
-BOOL (*PyObjC_class_addMethod)(Class, SEL, IMP, const char*) = NULL;
-BOOL (*PyObjC_class_addMethodList)(Class, struct PyObjC_method*, unsigned int) = NULL;
-Ivar* (*PyObjC_class_copyIvarList)(Class, unsigned int*) = NULL;
-Protocol** (*PyObjC_class_copyProtocolList)(Class, unsigned int*) = NULL;
-BOOL (*PyObjC_class_isMetaClass)(Class) = NULL;
-SEL (*PyObjC_method_getName)(Method m) = NULL;
-IMP (*PyObjC_method_getImplementation)(Method m) = NULL;
-IMP (*PyObjC_method_setImplementation)(Method m, IMP imp) = NULL;
-const char* (*PyObjC_method_getTypeEncoding)(Method m) = NULL;
-BOOL (*PyObjC_sel_isEqual)(SEL, SEL) = NULL;
-const char* (*PyObjC_ivar_getName)(Ivar) = NULL;
-const char* (*PyObjC_ivar_getTypeEncoding)(Ivar) = NULL;
-ptrdiff_t (*PyObjC_ivar_getOffset)(Ivar) = NULL;
+BOOL (*PyObjC_preclass_addProtocol)(Class cls, Protocol* protocol)               = NULL;
+Class (*PyObjC_object_getClass)(id obj)                                          = NULL;
+Class (*PyObjC_object_setClass)(id obj, Class cls)                               = NULL;
+const char* (*PyObjC_object_getClassName)(id obj)                                = NULL;
+Method* (*PyObjC_class_copyMethodList)(Class, unsigned int*)                     = NULL;
+const char* (*PyObjC_class_getName)(Class)                                       = NULL;
+size_t (*PyObjC_class_getInstanceSize)(Class)                                    = NULL;
+Class (*PyObjC_class_getSuperclass)(Class)                                       = NULL;
+BOOL (*PyObjC_class_addMethod)(Class, SEL, IMP, const char*)                     = NULL;
+BOOL (*PyObjC_class_addMethodList)(Class, struct PyObjC_method*, unsigned int)   = NULL;
+Ivar* (*PyObjC_class_copyIvarList)(Class, unsigned int*)                         = NULL;
+Protocol** (*PyObjC_class_copyProtocolList)(Class, unsigned int*)                = NULL;
+BOOL (*PyObjC_class_isMetaClass)(Class)                                          = NULL;
+SEL (*PyObjC_method_getName)(Method m)                                           = NULL;
+IMP (*PyObjC_method_getImplementation)(Method m)                                 = NULL;
+IMP (*PyObjC_method_setImplementation)(Method m, IMP imp)                        = NULL;
+const char* (*PyObjC_method_getTypeEncoding)(Method m)                           = NULL;
+BOOL (*PyObjC_sel_isEqual)(SEL, SEL)                                             = NULL;
+const char* (*PyObjC_ivar_getName)(Ivar)                                         = NULL;
+const char* (*PyObjC_ivar_getTypeEncoding)(Ivar)                                 = NULL;
+ptrdiff_t (*PyObjC_ivar_getOffset)(Ivar)                                         = NULL;
 
 #else /* (MAC_OS_X_VERSION_MIN_REQUIRED >= MAC_OS_X_VERSION_10_5) || defined(__OBJC2__)  \
        */
@@ -853,8 +853,8 @@ BOOL
 PyObjC_class_addMethodList(Class cls, struct PyObjC_method* list, unsigned int count)
 {
     unsigned int i;
-    BOOL r;
-    Method m;
+    BOOL         r;
+    Method       m;
 
     for (i = 0; i < count; i++) {
         /*
@@ -908,17 +908,17 @@ PyObjC_class_addMethodList(Class cls, struct PyObjC_method* list, unsigned int c
 #endif /* __x86_64__ */
 
 #if (MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_7)
-Protocol* (*PyObjC_objc_allocateProtocol)(const char*) = NULL;
-void (*PyObjC_objc_registerProtocol)(Protocol*) = NULL;
+Protocol* (*PyObjC_objc_allocateProtocol)(const char*)    = NULL;
+void (*PyObjC_objc_registerProtocol)(Protocol*)           = NULL;
 void (*PyObjC_protocol_addMethodDescription)(Protocol*, SEL, const char*, BOOL,
-                                             BOOL) = NULL;
+                                             BOOL)        = NULL;
 void (*PyObjC_protocol_addProtocol)(Protocol*, Protocol*) = NULL;
 
 #ifndef __LP64__
 struct Protocol_struct {
-    Class _isa;
-    char* protocol_name;
-    struct objc_protocol_list* protocol_list;
+    Class                                _isa;
+    char*                                protocol_name;
+    struct objc_protocol_list*           protocol_list;
     struct objc_method_description_list *instance_methods, *class_methods;
     struct objc_method_description_list *optional_instance_methods,
         *optional_class_methods;
@@ -939,12 +939,12 @@ compat_objc_allocateProtocol(const char* name)
         /* Leaking object */
         return NULL;
     }
-    result->protocol_list = NULL;
-    result->instance_methods = NULL;
-    result->class_methods = NULL;
+    result->protocol_list             = NULL;
+    result->instance_methods          = NULL;
+    result->class_methods             = NULL;
     result->optional_instance_methods = NULL;
-    result->optional_class_methods = NULL;
-    result->instance_properties = NULL;
+    result->optional_class_methods    = NULL;
+    result->instance_properties       = NULL;
     return (Protocol*)result;
 }
 
@@ -960,7 +960,7 @@ static void
 compat_protocol_addMethodDescription(Protocol* proto, SEL sel, const char* types,
                                      BOOL required, BOOL instance_method)
 {
-    struct Protocol_struct* proto_struct = (struct Protocol_struct*)proto;
+    struct Protocol_struct*               proto_struct = (struct Protocol_struct*)proto;
     struct objc_method_description_list** plist;
 
     if (!instance_method) {
@@ -979,8 +979,8 @@ compat_protocol_addMethodDescription(Protocol* proto, SEL sel, const char* types
     }
 
     if (*plist == NULL) {
-        *plist = malloc(sizeof(struct objc_method_description_list) +
-                        (2 * sizeof(struct objc_method_description)));
+        *plist = malloc(sizeof(struct objc_method_description_list)
+                        + (2 * sizeof(struct objc_method_description)));
         if (*plist == NULL) {
             /* Cannot report errors */
             abort();
@@ -990,15 +990,16 @@ compat_protocol_addMethodDescription(Protocol* proto, SEL sel, const char* types
 
     } else {
         *plist = realloc(
-            *plist, sizeof(struct objc_method_description_list) +
-                        (2 + ((*plist)->count) * sizeof(struct objc_method_description)));
+            *plist,
+            sizeof(struct objc_method_description_list)
+                + (2 + ((*plist)->count) * sizeof(struct objc_method_description)));
         if (*plist == NULL) {
             /* Cannot report errors */
             abort();
         }
     }
 
-    (*plist)->list[(*plist)->count].name = sel;
+    (*plist)->list[(*plist)->count].name  = sel;
     (*plist)->list[(*plist)->count].types = strdup(types);
 
     if ((*plist)->list[(*plist)->count].types == NULL) {
@@ -1008,7 +1009,7 @@ compat_protocol_addMethodDescription(Protocol* proto, SEL sel, const char* types
 
     (*plist)->count++;
 
-    (*plist)->list[(*plist)->count].name = NULL;
+    (*plist)->list[(*plist)->count].name  = NULL;
     (*plist)->list[(*plist)->count].types = NULL;
 }
 
@@ -1024,19 +1025,19 @@ compat_protocol_addProtocol(Protocol* proto, Protocol* newProto)
             /* Cannot report an error! */
             abort();
         }
-        proto_struct->protocol_list->next = NULL;
+        proto_struct->protocol_list->next  = NULL;
         proto_struct->protocol_list->count = 0;
     } else {
         proto_struct->protocol_list =
             realloc(proto_struct->protocol_list,
-                    sizeof(struct objc_protocol_list) +
-                        (2 + proto_struct->protocol_list->count) * sizeof(Protocol*));
+                    sizeof(struct objc_protocol_list)
+                        + (2 + proto_struct->protocol_list->count) * sizeof(Protocol*));
         if (proto_struct->protocol_list == NULL) {
             /* Cannot report an error! */
             abort();
         }
     }
-    proto_struct->protocol_list->list[proto_struct->protocol_list->count] = newProto;
+    proto_struct->protocol_list->list[proto_struct->protocol_list->count]     = newProto;
     proto_struct->protocol_list->list[proto_struct->protocol_list->count + 1] = NULL;
     proto_struct->protocol_list->count++;
 }
@@ -1064,7 +1065,7 @@ PyObjC_protocol_getMethodDescription(Protocol* p, SEL aSel, BOOL isRequiredMetho
          */
 
         struct objc_method_description* methods;
-        unsigned int count, i;
+        unsigned int                    count, i;
         methods = protocol_copyMethodDescriptionList(p, isRequiredMethod,
                                                      isInstanceMethod, &count);
         if (methods == NULL) {
@@ -1095,25 +1096,25 @@ PyObjC_SetupRuntimeCompat(void)
      * Don't use ObjC 2.0 runtime (compiling on 10.4 or earlier), always
      * use the compat implementation.
      */
-    PyObjC_class_addMethodList = compat_class_addMethodList;
+    PyObjC_class_addMethodList   = compat_class_addMethodList;
     PyObjC_objc_disposeClassPair = compat_objc_disposeClassPair;
-    PyObjC_preclass_addMethod = compat_preclass_addMethod;
-    PyObjC_preclass_addIvar = compat_preclass_addIvar;
-    PyObjC_preclass_addProtocol = compat_preclass_addProtocol;
+    PyObjC_preclass_addMethod    = compat_preclass_addMethod;
+    PyObjC_preclass_addIvar      = compat_preclass_addIvar;
+    PyObjC_preclass_addProtocol  = compat_preclass_addProtocol;
 
 #define SETUP(funcname) PyObjC_##funcname = compat_##funcname
 
 #else /* !NO_OBJC2_RUNTIME */
 
     if (class_addMethod) {
-        PyObjC_class_addMethodList = objc20_class_addMethodList;
-        PyObjC_preclass_addMethod = class_addMethod;
-        PyObjC_preclass_addIvar = class_addIvar;
+        PyObjC_class_addMethodList  = objc20_class_addMethodList;
+        PyObjC_preclass_addMethod   = class_addMethod;
+        PyObjC_preclass_addIvar     = class_addIvar;
         PyObjC_preclass_addProtocol = class_addProtocol;
     } else {
-        PyObjC_class_addMethodList = compat_class_addMethodList;
-        PyObjC_preclass_addMethod = compat_preclass_addMethod;
-        PyObjC_preclass_addIvar = compat_preclass_addIvar;
+        PyObjC_class_addMethodList  = compat_class_addMethodList;
+        PyObjC_preclass_addMethod   = compat_preclass_addMethod;
+        PyObjC_preclass_addIvar     = compat_preclass_addIvar;
         PyObjC_preclass_addProtocol = compat_preclass_addProtocol;
     }
 
@@ -1178,17 +1179,17 @@ PyObjC_SetupRuntimeCompat(void)
 #if PyObjC_BUILD_RELEASE < 1007
 
 #ifndef __LP64__
-    PyObjC_objc_allocateProtocol = compat_objc_allocateProtocol;
-    PyObjC_objc_registerProtocol = compat_objc_registerProtocol;
+    PyObjC_objc_allocateProtocol         = compat_objc_allocateProtocol;
+    PyObjC_objc_registerProtocol         = compat_objc_registerProtocol;
     PyObjC_protocol_addMethodDescription = compat_protocol_addMethodDescription;
-    PyObjC_protocol_addProtocol = compat_protocol_addProtocol;
+    PyObjC_protocol_addProtocol          = compat_protocol_addProtocol;
 #endif /* __LP64__ */
 
 #elif defined(__LP64__)
-    PyObjC_objc_allocateProtocol = objc_allocateProtocol;
-    PyObjC_objc_registerProtocol = objc_registerProtocol;
+    PyObjC_objc_allocateProtocol         = objc_allocateProtocol;
+    PyObjC_objc_registerProtocol         = objc_registerProtocol;
     PyObjC_protocol_addMethodDescription = protocol_addMethodDescription;
-    PyObjC_protocol_addProtocol = protocol_addProtocol;
+    PyObjC_protocol_addProtocol          = protocol_addProtocol;
 
 #else /* PyObjC_BUILD_RELEASE >= 1007 && !__LP64 */
 #define SETUP(funcname)                                                                  \
