@@ -1,11 +1,12 @@
 # Tests for interaction with ObjC "blocks".
 #
 # These tests are fairly minimal at the moment.
-from PyObjCTools.TestSupport import *
-from PyObjCTest.block import OCTestBlock
-import objc
 import sys
 
+import objc
+from PyObjCTest.block import OCTestBlock
+from PyObjCTools.TestSupport import TestCase, main, onlyIf, min_os_level
+
 if sys.maxsize > 2 ** 32:
     NSRect_tp = b"{CGRect={CGPoint=dd}{CGSize=dd}}"
 else:
@@ -119,9 +120,7 @@ objc.parseBridgeSupport(
       </class>
     </signatures>
     """
-    % dict(
-        NSRect_tp=NSRect_tp if sys.version_info[0] == 2 else NSRect_tp.decode("ascii")
-    ),
+    % {"NSRect_tp": NSRect_tp.decode("ascii")},
     globals(),
     "PyObjCTest",
 )
@@ -225,6 +224,32 @@ class TestBlocks(TestCase):
         self.assertEqual(len(helper.values), 2)
         self.assertEqual(helper.values, [42, 43])
 
+    @min_os_level("10.6")
+    @onlyIf(blocksEnabled, "no blocks")
+    def test_block_with_varargs(self):
+        obj = OCTestBlock.alloc().init()
+
+        class C:
+            def __init__(self):
+                self._called = 0
+
+            def callback(*args):
+                args[0]._called += 1
+
+        helper = C()
+        obj.callIntBlock_withValue_(helper.callback, 43)
+        self.assertEqual(helper._called, 1)
+
+        class D:
+            def __init__(self):
+                self._called = 0
+
+            def callback():
+                pass
+
+        helper = D()
+        self.assertRaises(TypeError, obj.callIntBlock_withValue_, helper.callback, 43)
+
     @min_os_level("10.6")
     @onlyIf(blocksEnabled, "no blocks")
     def testStackBlocksWithDirectUse(self):
@@ -266,21 +291,21 @@ class TestBlocks(TestCase):
     def testBlockToObjC2(self):
         obj = OCTestBlock.alloc().init()
 
-        lst = []
-
         def callback(a, b):
             return a * b
 
-        self.assertEqual(obj.callDoubleBlock_withValue_andValue_(callback, 2.0, 3.5), 7.0)
-        self.assertEqual(obj.callDoubleBlock_withValue_andValue_(callback, 2.5, 10), 25.0)
+        self.assertEqual(
+            obj.callDoubleBlock_withValue_andValue_(callback, 2.0, 3.5), 7.0
+        )
+        self.assertEqual(
+            obj.callDoubleBlock_withValue_andValue_(callback, 2.5, 10), 25.0
+        )
 
     @min_os_level("10.6")
     @onlyIf(blocksEnabled, "no blocks")
     def testBlockToObjC3(self):
         obj = OCTestBlock.alloc().init()
 
-        lst = []
-
         def callback(a, b, c, d):
             return ((a, b), (c, d))
 
@@ -327,7 +352,9 @@ class TestBlocks(TestCase):
 
         block = obj.getFloatBlock()
         sig = objc.splitSignature(objc._block_signature(block))
-        self.assertEqual(sig, (objc._C_DBL, objc._C_ID + b"?", objc._C_DBL, objc._C_DBL))
+        self.assertEqual(
+            sig, (objc._C_DBL, objc._C_ID + b"?", objc._C_DBL, objc._C_DBL)
+        )
 
         block = obj.getStructBlock()
         sig = objc.splitSignature(objc._block_signature(block))
