@@ -1,12 +1,11 @@
 """
 Testcases for the CoreFoundation wrappers introduced in 1.5
 """
-import objc
-from PyObjCTools.TestSupport import *
 import re
-import sys
 
-from PyObjCTest.corefoundation import *
+import objc
+from PyObjCTest.corefoundation import OC_TestCoreFoundation
+from PyObjCTools.TestSupport import TestCase, main
 
 # registerCFSignature(name, encoding, typeId [, tollfreeName]) -> type
 
@@ -23,9 +22,6 @@ CFDateRef = objc.registerCFSignature(
     "NSDate",
 )
 
-if sys.version_info[0] == 3:
-    unicode = str
-
 
 class TestCoreFoundation(TestCase):
     def testTollFree(self):
@@ -35,17 +31,14 @@ class TestCoreFoundation(TestCase):
         self.assertIsInstance(obj, CFDateRef)
 
         v = OC_TestCoreFoundation.formatDate_(obj)
-        self.assertIsInstance(v, unicode)
+        self.assertIsInstance(v, str)
 
         formatter = objc.lookUpClass("NSDateFormatter").new()
         formatter.setDateStyle_(OC_TestCoreFoundation.shortStyle())
-        formatter.setTimeStyle_(OC_TestCoreFoundation.shortStyle())
+        formatter.setTimeStyle_(OC_TestCoreFoundation.noStyle())
         formatter.setLocale_(objc.lookUpClass("NSLocale").currentLocale())
         v2 = formatter.stringForObjectValue_(obj)
-
-        # Arggh, I'm an idiot: the code above doesn't calculate the same
-        # string as the C code in corefoundation.m.
-        # print v , v2
+        self.assertEqual(v2, v)
 
     def testBridged(self):
 
@@ -55,10 +48,11 @@ class TestCoreFoundation(TestCase):
 
         formatted = OC_TestCoreFoundation.formatUUID_(obj)
 
-        self.assertIsInstance(formatted, unicode)
+        self.assertIsInstance(formatted, str)
         self.assertTrue(
             re.match(
-                r"[A-Z0-9]{8}-[A-Z0-9]{4}-[A-Z0-9]{4}-[A-Z0-9]{4}-[A-Z0-9]{12}", formatted
+                r"[A-Z0-9]{8}-[A-Z0-9]{4}-[A-Z0-9]{4}-[A-Z0-9]{4}-[A-Z0-9]{12}",
+                formatted,
             )
         )
 
@@ -72,10 +66,11 @@ class TestCoreFoundation(TestCase):
 
         formatted = OC_TestCoreFoundation.formatUUID_(obj)
 
-        self.assertIsInstance(formatted, unicode)
+        self.assertIsInstance(formatted, str)
         self.assertTrue(
             re.match(
-                r"[A-Z0-9]{8}-[A-Z0-9]{4}-[A-Z0-9]{4}-[A-Z0-9]{4}-[A-Z0-9]{12}", formatted
+                r"[A-Z0-9]{8}-[A-Z0-9]{4}-[A-Z0-9]{4}-[A-Z0-9]{4}-[A-Z0-9]{12}",
+                formatted,
             )
         )
 
