@@ -3,17 +3,10 @@ Minimal tests for sequence proxies
 
 NOTE: this file is very, very incomplete and just tests copying at the moment.
 """
-import sys
-from PyObjCTools.TestSupport import *
-from PyObjCTest.fnd import (
-    NSDictionary,
-    NSMutableDictionary,
-    NSPredicate,
-    NSObject,
-    NSNull,
-)
-from PyObjCTest.pythonset import OC_TestSet
+
 import objc
+from PyObjCTest.pythonset import OC_TestSet
+from PyObjCTools.TestSupport import TestCase, main
 
 OC_PythonDictionary = objc.lookUpClass("OC_PythonDictionary")
 OC_BuiltinPythonDictionary = objc.lookUpClass("OC_BuiltinPythonDictionary")
