@@ -11,8 +11,9 @@ method defintions:
         o.myMethod_() # should also work, arg == 1
 """
 
-from PyObjCTools.TestSupport import *
 from PyObjCTest.fnd import NSObject
+from PyObjCTools.TestSupport import TestCase, main
+import objc
 
 
 class TestInheritedProtoype(TestCase):
@@ -378,7 +379,7 @@ class TestExplicitPrototype(TestCase):
             oneoutput_ = objc.selector(oneoutput_, signature=b"i@:^@")
 
         class OC_ExplProto_OutputPresent2(NSObject):
-            def oneinput_output_(self, input, output):
+            def oneinput_output_(self, input_value, output_value):
                 pass
 
             oneinput_output_ = objc.selector(oneinput_output_, signature=b"i@:f^@")
@@ -404,7 +405,7 @@ class TestExplicitPrototype(TestCase):
         try:
 
             class OC_ExplProto_OutputAbsent2(NSObject):
-                def oneinput_output_(self, input):
+                def oneinput_output_(self, value):
                     pass
 
                 oneinput_output_ = objc.selector(oneinput_output_, signature=b"i@:i^@")
@@ -435,7 +436,9 @@ class TestImplicitSignature(TestCase):
             def simplemethod(self):
                 pass
 
-        self.assertEqual(OC_ImplProto_ColonMatch1.simplemethod.selector, b"simplemethod")
+        self.assertEqual(
+            OC_ImplProto_ColonMatch1.simplemethod.selector, b"simplemethod"
+        )
         self.assertEqual(OC_ImplProto_ColonMatch1.simplemethod.signature, b"v@:")
 
         class OC_ImplProto_ColonMatch2(NSObject):
@@ -445,7 +448,9 @@ class TestImplicitSignature(TestCase):
         self.assertEqual(
             OC_ImplProto_ColonMatch2.simplemethod_arg2_.selector, b"simplemethod:arg2:"
         )
-        self.assertEqual(OC_ImplProto_ColonMatch2.simplemethod_arg2_.signature, b"@@:@@")
+        self.assertEqual(
+            OC_ImplProto_ColonMatch2.simplemethod_arg2_.signature, b"@@:@@"
+        )
 
     def testTooFewColons(self):
         # OK: the number of implied colons is smaller than the actual number of
@@ -579,7 +584,9 @@ class TestImplicitSignature(TestCase):
             b"method_with_embedded_underscores",
         )
         # self.assertEqual(OC_ImplProto_Variations.__magic__.selector, b"__magic__")
-        self.assertEqual(OC_ImplProto_Variations._leadingColon.selector, b"_leadingColon")
+        self.assertEqual(
+            OC_ImplProto_Variations._leadingColon.selector, b"_leadingColon"
+        )
         self.assertEqual(
             OC_ImplProto_Variations._leadingColon_.selector, b"_leadingColon:"
         )
