@@ -31,63 +31,61 @@ NOTES:
 - See also testbndl.m, the implementation there must be synchronized
   with this file.
 """
-from __future__ import unicode_literals
-from PyObjCTools.TestSupport import *
-import objc
-import sys
 import struct
+import sys
 import warnings
 
+import objc
+from PyObjCTest.testbndl import OC_TestClass1, OC_TestClass2
+from PyObjCTools.TestSupport import TestCase, main
+
 # Can't set the right signatures in plain Objective-C.
 for method, argmeta in [
-    (b"passInOutChar:", {2: dict(type_modifier=b"N")}),
-    (b"passOutChar:", {2: dict(type_modifier=b"o")}),
-    (b"passInChar:", {2: dict(type_modifier=b"n")}),
-    (b"passInOutUChar:", {2: dict(type_modifier=b"N", type="^C")}),
-    (b"passOutUChar:", {2: dict(type_modifier=b"o", type="^C")}),
-    (b"passInUChar:", {2: dict(type_modifier=b"n", type="^C")}),
-    (b"passInOutShort:", {2: dict(type_modifier=b"N")}),
-    (b"passOutShort:", {2: dict(type_modifier=b"o")}),
-    (b"passInShort:", {2: dict(type_modifier=b"n")}),
-    (b"passInOutUShort:", {2: dict(type_modifier=b"N")}),
-    (b"passOutUShort:", {2: dict(type_modifier=b"o")}),
-    (b"passInUShort:", {2: dict(type_modifier=b"n")}),
-    (b"passInOutInt:", {2: dict(type_modifier=b"N")}),
-    (b"passOutInt:", {2: dict(type_modifier=b"o")}),
-    (b"passInInt:", {2: dict(type_modifier=b"n")}),
-    (b"passInOutUInt:", {2: dict(type_modifier=b"N")}),
-    (b"passOutUInt:", {2: dict(type_modifier=b"o")}),
-    (b"passInUInt:", {2: dict(type_modifier=b"n")}),
-    (b"passInOutLong:", {2: dict(type_modifier=b"N")}),
-    (b"passOutLong:", {2: dict(type_modifier=b"o")}),
-    (b"passInLong:", {2: dict(type_modifier=b"n")}),
-    (b"passInOutULong:", {2: dict(type_modifier=b"N")}),
-    (b"passOutULong:", {2: dict(type_modifier=b"o")}),
-    (b"passInULong:", {2: dict(type_modifier=b"n")}),
-    (b"passInOutLongLong:", {2: dict(type_modifier=b"N")}),
-    (b"passOutLongLong:", {2: dict(type_modifier=b"o")}),
-    (b"passInLongLong:", {2: dict(type_modifier=b"n")}),
-    (b"passInOutULongLong:", {2: dict(type_modifier=b"N")}),
-    (b"passOutULongLong:", {2: dict(type_modifier=b"o")}),
-    (b"passInULongLong:", {2: dict(type_modifier=b"n")}),
-    (b"passInOutFloat:", {2: dict(type_modifier=b"N")}),
-    (b"passOutFloat:", {2: dict(type_modifier=b"o")}),
-    (b"passInFloat:", {2: dict(type_modifier=b"n")}),
-    (b"passInOutDouble:", {2: dict(type_modifier=b"N")}),
-    (b"passOutDouble:", {2: dict(type_modifier=b"o")}),
-    (b"passInDouble:", {2: dict(type_modifier=b"n")}),
-    (b"passInOutCharp:", {2: dict(type_modifier=b"N")}),
-    (b"passOutCharp:", {2: dict(type_modifier=b"o")}),
-    (b"passInCharp:", {2: dict(type_modifier=b"n")}),
-    (b"passInOutID:", {2: dict(type_modifier=b"N")}),
-    (b"passOutID:", {2: dict(type_modifier=b"o")}),
-    (b"passInID:", {2: dict(type_modifier=b"n")}),
+    (b"passInOutChar:", {2: {"type_modifier": b"N"}}),
+    (b"passOutChar:", {2: {"type_modifier": b"o"}}),
+    (b"passInChar:", {2: {"type_modifier": b"n"}}),
+    (b"passInOutUChar:", {2: {"type_modifier": b"N", "type": "^C"}}),
+    (b"passOutUChar:", {2: {"type_modifier": b"o", "type": "^C"}}),
+    (b"passInUChar:", {2: {"type_modifier": b"n", "type": "^C"}}),
+    (b"passInOutShort:", {2: {"type_modifier": b"N"}}),
+    (b"passOutShort:", {2: {"type_modifier": b"o"}}),
+    (b"passInShort:", {2: {"type_modifier": b"n"}}),
+    (b"passInOutUShort:", {2: {"type_modifier": b"N"}}),
+    (b"passOutUShort:", {2: {"type_modifier": b"o"}}),
+    (b"passInUShort:", {2: {"type_modifier": b"n"}}),
+    (b"passInOutInt:", {2: {"type_modifier": b"N"}}),
+    (b"passOutInt:", {2: {"type_modifier": b"o"}}),
+    (b"passInInt:", {2: {"type_modifier": b"n"}}),
+    (b"passInOutUInt:", {2: {"type_modifier": b"N"}}),
+    (b"passOutUInt:", {2: {"type_modifier": b"o"}}),
+    (b"passInUInt:", {2: {"type_modifier": b"n"}}),
+    (b"passInOutLong:", {2: {"type_modifier": b"N"}}),
+    (b"passOutLong:", {2: {"type_modifier": b"o"}}),
+    (b"passInLong:", {2: {"type_modifier": b"n"}}),
+    (b"passInOutULong:", {2: {"type_modifier": b"N"}}),
+    (b"passOutULong:", {2: {"type_modifier": b"o"}}),
+    (b"passInULong:", {2: {"type_modifier": b"n"}}),
+    (b"passInOutLongLong:", {2: {"type_modifier": b"N"}}),
+    (b"passOutLongLong:", {2: {"type_modifier": b"o"}}),
+    (b"passInLongLong:", {2: {"type_modifier": b"n"}}),
+    (b"passInOutULongLong:", {2: {"type_modifier": b"N"}}),
+    (b"passOutULongLong:", {2: {"type_modifier": b"o"}}),
+    (b"passInULongLong:", {2: {"type_modifier": b"n"}}),
+    (b"passInOutFloat:", {2: {"type_modifier": b"N"}}),
+    (b"passOutFloat:", {2: {"type_modifier": b"o"}}),
+    (b"passInFloat:", {2: {"type_modifier": b"n"}}),
+    (b"passInOutDouble:", {2: {"type_modifier": b"N"}}),
+    (b"passOutDouble:", {2: {"type_modifier": b"o"}}),
+    (b"passInDouble:", {2: {"type_modifier": b"n"}}),
+    (b"passInOutCharp:", {2: {"type_modifier": b"N"}}),
+    (b"passOutCharp:", {2: {"type_modifier": b"o"}}),
+    (b"passInCharp:", {2: {"type_modifier": b"n"}}),
+    (b"passInOutID:", {2: {"type_modifier": b"N"}}),
+    (b"passOutID:", {2: {"type_modifier": b"o"}}),
+    (b"passInID:", {2: {"type_modifier": b"n"}}),
 ]:
 
-    objc.registerMetaDataForSelector(b"OC_TestClass1", method, dict(arguments=argmeta))
-
-
-from PyObjCTest.testbndl import *
+    objc.registerMetaDataForSelector(b"OC_TestClass1", method, {"arguments": argmeta})
 
 
 def makeCFloat(value):
@@ -95,12 +93,7 @@ def makeCFloat(value):
     C floats and doubles have a different representation, this function returns
     the result of converting a python float (== C double) to a C float and back.
     """
-    if sys.version_info[0] == 2:
-        struct_fmt = b"f"
-    else:
-        struct_fmt = "f"
-
-    return struct.unpack(struct_fmt, struct.pack(struct_fmt, value))[0]
+    return struct.unpack("f", struct.pack("f", value))[0]
 
 
 class PyOCTestSimpleReturns(TestCase):
@@ -1125,9 +1118,15 @@ class OCPyTestSimpleCalls(TestCase):
         for o in UINT_NUMBERS[:-3]:
             self.assertEqual(self.obj.callInstanceUnsignedIntFuncOf_(self.ocobj), o)
 
-        self.assertRaises(ValueError, self.obj.callInstanceUnsignedIntFuncOf_, self.ocobj)
-        self.assertRaises(ValueError, self.obj.callInstanceUnsignedIntFuncOf_, self.ocobj)
-        self.assertRaises(ValueError, self.obj.callInstanceUnsignedIntFuncOf_, self.ocobj)
+        self.assertRaises(
+            ValueError, self.obj.callInstanceUnsignedIntFuncOf_, self.ocobj
+        )
+        self.assertRaises(
+            ValueError, self.obj.callInstanceUnsignedIntFuncOf_, self.ocobj
+        )
+        self.assertRaises(
+            ValueError, self.obj.callInstanceUnsignedIntFuncOf_, self.ocobj
+        )
 
     def testIUInt(self):
         self.pyobj.reset()
@@ -1220,16 +1219,24 @@ class OCPyTestSimpleCalls(TestCase):
         for o in LONGLONG_NUMBERS[:-3]:
             self.assertEqual(self.obj.invokeInstanceLongLongFuncOf_(self.ocobj), o)
 
-        self.assertRaises(ValueError, self.obj.invokeInstanceLongLongFuncOf_, self.ocobj)
-        self.assertRaises(ValueError, self.obj.invokeInstanceLongLongFuncOf_, self.ocobj)
-        self.assertRaises(ValueError, self.obj.invokeInstanceLongLongFuncOf_, self.ocobj)
+        self.assertRaises(
+            ValueError, self.obj.invokeInstanceLongLongFuncOf_, self.ocobj
+        )
+        self.assertRaises(
+            ValueError, self.obj.invokeInstanceLongLongFuncOf_, self.ocobj
+        )
+        self.assertRaises(
+            ValueError, self.obj.invokeInstanceLongLongFuncOf_, self.ocobj
+        )
 
     def testCULongLong(self):
         self.pyobj.reset()
         self.ocobj.reset()
 
         for o in ULONGLONG_NUMBERS[:-3]:
-            self.assertEqual(self.obj.callInstanceUnsignedLongLongFuncOf_(self.ocobj), o)
+            self.assertEqual(
+                self.obj.callInstanceUnsignedLongLongFuncOf_(self.ocobj), o
+            )
 
         self.assertRaises(
             ValueError, self.obj.callInstanceUnsignedLongLongFuncOf_, self.ocobj
