@@ -1,11 +1,10 @@
-from __future__ import unicode_literals
-from PyObjCTools.TestSupport import *
+import sys
+
 import objc
 from PyObjCTest.testbndl import PyObjC_TestClass4
-from . import fnd as Foundation
-from .fnd import NSObject, NSArray, NSAttributedString
-import sys
-import os
+from PyObjCTools.TestSupport import TestCase, main
+
+from .fnd import NSArray, NSAttributedString, NSObject
 
 
 class TestConstants(TestCase):
@@ -30,8 +29,6 @@ class TestClassLookup(TestCase):
         self.assertRaises(TypeError, objc.lookUpClass, 1)
 
     def testClassList(self):
-        ###! This test should probably be moved down to the Foundation test suite...
-
         NSObject = objc.lookUpClass("NSObject")
         NSException = objc.lookUpClass("NSException")
         NSMutableArray = objc.lookUpClass("NSMutableArray")
@@ -86,15 +83,6 @@ class TestPickle(TestCase):
         self.assertRaises((TypeError, ValueError), pickle.dumps, o, 1)
         self.assertRaises((TypeError, ValueError), pickle.dumps, o, 2)
 
-    @onlyPython2
-    def testCPicklePure(self):
-        import cPickle as pickle
-
-        o = NSObject.alloc().init()
-        self.assertRaises((TypeError, ValueError), pickle.dumps, o, 0)
-        self.assertRaises((TypeError, ValueError), pickle.dumps, o, 1)
-        self.assertRaises((TypeError, ValueError), pickle.dumps, o, 2)
-
 
 class TestDescription(TestCase):
     def testSimple(self):
